@@ -33,13 +33,13 @@ func TestTable(t *testing.T) {
 				},
 			},
 			expected: []string{
-				`+---------+----------------------------------+-----------+---------------+`,
-				`| RESULT  |               FILE               | NAMESPACE |    MESSAGE    |`,
-				`+---------+----------------------------------+-----------+---------------+`,
-				`| warning | examples/kubernetes/service.yaml | namespace | first warning |`,
-				`| skipped | examples/kubernetes/service.yaml | namespace | first skipped |`,
-				`| failure | examples/kubernetes/service.yaml | namespace | first failure |`,
-				`+---------+----------------------------------+-----------+---------------+`,
+				`┌─────────┬──────────────────────────────────┬───────────┬───────────────┐`,
+				`│ RESULT  │               FILE               │ NAMESPACE │    MESSAGE    │`,
+				`├─────────┼──────────────────────────────────┼───────────┼───────────────┤`,
+				`│ warning │ examples/kubernetes/service.yaml │ namespace │ first warning │`,
+				`│ skipped │ examples/kubernetes/service.yaml │ namespace │ first skipped │`,
+				`│ failure │ examples/kubernetes/service.yaml │ namespace │ first failure │`,
+				`└─────────┴──────────────────────────────────┴───────────┴───────────────┘`,
 				``,
 			},
 		},
