@@ -9,7 +9,7 @@ func TestVCLParser(t *testing.T) {
 	"localhost";
 }`
 
-	var input interface{}
+	var input any
 	if err := parser.Unmarshal([]byte(sample), &input); err != nil {
 		t.Fatalf("parser should not have thrown an error: %v", err)
 	}
@@ -18,7 +18,7 @@ func TestVCLParser(t *testing.T) {
 		t.Error("there should be information parsed but its nil")
 	}
 
-	item := input.(map[string]interface{})
+	item := input.(map[string]any)
 
 	if len(item) == 0 {
 		t.Error("there should be at least one item defined in the parsed file, but none found")
