@@ -4,7 +4,7 @@ set -eo pipefail
 
 code=0
 while read -r commit; do
-    match=$(echo "${commit}" | grep -o -h -E "^[a-z]+(\([a-z]+\))?: " || true)
+    match=$(echo "${commit}" | grep -o -h -E "^[a-z]+(\([a-z-]+\))?: " || true)
     if [[ -z "${match}" ]]; then
         echo "::error::Commit \"${commit}\" does not have the required conventional commit prefix. See https://www.conventionalcommits.org/ for more info."
         code=1
